@@ -79,28 +79,28 @@ class ID3Hack(ID3):
 class MP3TagsWrapper(FreeformTagsWrapper):
     __raw_class__ = ID3Hack
     __handlers__ = {
-        'album':           MP3TextTagHandler('TALB'),
-        'albumartist':     MP3TextTagHandler('TPE2'),
-        'albumartistsort': MP3TextTagHandler('TSO2'),
-        'albumsort':       MP3TextTagHandler('TSOA'),
-        'artist':          MP3TextTagHandler('TPE1'),
-        'artistsort':      MP3TextTagHandler('TSOP'),
-        'composer':        MP3TextTagHandler('TCOM'),
-        'composersort':    MP3TextTagHandler('TSOC'),
-        'conductor':       MP3TextTagHandler('TPE3'),
-        'copyright':       MP3TextTagHandler('TCOP'),
-        'date':            MP3DateTagHandler('TDRC'),
-        'discnumber':      MP3PairTagHandler('TPOS', 0),
-        'disctotal':       MP3PairTagHandler('TPOS', 1),
-        'encodedby':       MP3TextTagHandler('TENC'),
-        'genre':           MP3TextTagHandler('TCON'),
-        'grouping':        MP3TextTagHandler('TIT1'),
-        'pictures':        MP3PictureTagHandler('APIC:'),
-        'title':           MP3TextTagHandler('TIT2'),
-        'titlesort':       MP3TextTagHandler('TSOT'),
-        'tracknumber':     MP3PairTagHandler('TRCK', 0),
-        'tracktotal':      MP3PairTagHandler('TRCK', 1),
-        'lyrics':          MP3TextTagHandler('TEXT'),
+        'album':                MP3TextTagHandler('TALB'),
+        'albumartist':          MP3TextTagHandler('TPE2'),
+        'albumartistsortorder': MP3TextTagHandler('TSO2'),
+        'albumsortorder':       MP3TextTagHandler('TSOA'),
+        'artist':               MP3TextTagHandler('TPE1'),
+        'artistsortorder':      MP3TextTagHandler('TSOP'),
+        'composer':             MP3TextTagHandler('TCOM'),
+        'composersortorder':    MP3TextTagHandler('TSOC'),
+        'conductor':            MP3TextTagHandler('TPE3'),
+        'copyright':            MP3TextTagHandler('TCOP'),
+        'date':                 MP3DateTagHandler('TDRC'),
+        'discnumber':           MP3PairTagHandler('TPOS', 0),
+        'disctotal':            MP3PairTagHandler('TPOS', 1),
+        'encodedby':            MP3TextTagHandler('TENC'),
+        'genre':                MP3TextTagHandler('TCON'),
+        'grouping':             MP3TextTagHandler('TIT1'),
+        'pictures':             MP3PictureTagHandler('APIC:'),
+        'title':                MP3TextTagHandler('TIT2'),
+        'titlesortorder':       MP3TextTagHandler('TSOT'),
+        'tracknumber':          MP3PairTagHandler('TRCK', 0),
+        'tracktotal':           MP3PairTagHandler('TRCK', 1),
+        'lyrics':               MP3TextTagHandler('TEXT'),
     }
     __freeform_pattern__ = '^TXXX:(.*)$'
     __freeform_format__ = 'TXXX:{0}'
