@@ -49,28 +49,28 @@ class MP4Hack(MP4):
 class MP4TagsWrapper(FreeformTagsWrapper):
     __raw_class__ = MP4Hack
     __handlers__ = {
-        'album':           TextTagHandler('\xa9alb'),
-        'albumartist':     TextTagHandler('aART'),
-        'albumartistsort': TextTagHandler('soaa'),
-        'albumsort':       TextTagHandler('soal'),
-        'artist':          TextTagHandler('\xa9ART'),
-        'artistsort':      TextTagHandler('soar'),
-        'comment':         TextTagHandler('\xa9cmt'),
-        'composer':        TextTagHandler('\xa9wrt'),
-        'composersort':    TextTagHandler('soco'),
-        'copyright':       TextTagHandler('cprt'),
-        'date':            TextTagHandler('\xa9day'),
-        'discnumber':      MP4PairTagHandler('disk', 0),
-        'disctotal':       MP4PairTagHandler('disk', 1),
-        'encodedby':       TextTagHandler('\xa9too'),
-        'genre':           TextTagHandler('\xa9gen'),
-        'grouping':        TextTagHandler('\xa9grp'),
-        'pictures':        TextTagHandler('covr'),
-        'title':           TextTagHandler('\xa9nam'),
-        'titlesort':       TextTagHandler('sonm'),
-        'tracknumber':     MP4PairTagHandler('trkn', 0),
-        'tracktotal':      MP4PairTagHandler('trkn', 1),
-        'lyrics':          TextTagHandler('\xa9lyr'),
+        'album':                TextTagHandler('\xa9alb'),
+        'albumartist':          TextTagHandler('aART'),
+        'albumartistsortorder': TextTagHandler('soaa'),
+        'albumsortorder':       TextTagHandler('soal'),
+        'artist':               TextTagHandler('\xa9ART'),
+        'artistsortorder':      TextTagHandler('soar'),
+        'comment':              TextTagHandler('\xa9cmt'),
+        'composer':             TextTagHandler('\xa9wrt'),
+        'composersortorder':    TextTagHandler('soco'),
+        'copyright':            TextTagHandler('cprt'),
+        'date':                 TextTagHandler('\xa9day'),
+        'discnumber':           MP4PairTagHandler('disk', 0),
+        'disctotal':            MP4PairTagHandler('disk', 1),
+        'encodedby':            TextTagHandler('\xa9too'),
+        'genre':                TextTagHandler('\xa9gen'),
+        'grouping':             TextTagHandler('\xa9grp'),
+        'pictures':             TextTagHandler('covr'),
+        'title':                TextTagHandler('\xa9nam'),
+        'titlesortorder':       TextTagHandler('sonm'),
+        'tracknumber':          MP4PairTagHandler('trkn', 0),
+        'tracktotal':           MP4PairTagHandler('trkn', 1),
+        'lyrics':               TextTagHandler('\xa9lyr'),
     }
     __freeform_pattern__ = '^----:com.apple.iTunes:(.*)$'
     __freeform_format__ = '----:com.apple.iTunes:{0}'
